| Package name                                                  | Package hash                                                  |
| ------------------------------------------------------------- | ------------------------------------------------------------- |
| protocol/fetchai/default/1.0.0                                | `bafybeih4zgjm7ifmovpzuwdobwb2kotvvr4gx3suwbn5j5z3pau4sioaou` |
| protocol/valory/acn/1.1.0                                     | `bafybeiea66z4k6cgcazxd6qzvnkllulyjzbnxufkoenge7qzh4qfogrvoa` |
| protocol/valory/contract_api/1.0.0                            | `bafybeibld2xb5m7kyluiptkamp4nrt6oeomkohz7a3yppbv2oo7qw2e4la` |
| protocol/valory/http/1.0.0                                    | `bafybeidxkp3vga7t6x2pbt2tpkgyaxa5bgpdgryao54py7w3yxyzr7neoy` |
| protocol/valory/ledger_api/1.0.0                              | `bafybeiecq56phjfws36rgrefw6niyo4ezesloodsfis647mpm5ygqo4ysi` |
| protocol/fetchai/fipa/1.0.0                                   | `bafybeiexw4ccraawqjsl6arrahkhuzo7fuhtqtkgal5v4mo7mmhzj7j76q` |
| protocol/fetchai/oef_search/1.0.0                             | `bafybeiardyypwak6lc5mmtcrle2vtozudc2fjn772fuk4kvu6ljgkwspg4` |
| protocol/fetchai/state_update/1.0.0                           | `bafybeidwosqpgupk7dylhzbwpyoj2bg6poajgjijjg5l5qh5d76slpgx64` |
| protocol/open_aea/signing/1.0.0                               | `bafybeifsjmldwyki3beqyvdt5lzenrg6wyrqaar5plc5rpnvtc4zlentye` |
| protocol/fetchai/tac/1.0.0                                    | `bafybeigrhtzciyh2r6pa4g3kpqqpg3uni2jt6u4ibhf6ayyd73e6kgqjwq` |
| contract/fetchai/erc1155/0.22.0                               | `bafybeidejj3rt3agmwrcncff7jrbpv6obknhpwi24wr7qq2ufi2b2gswoy` |
| connection/fetchai/stub/0.21.0                                | `bafybeihjlr7xeurjm56ckji3gjjlao4pykkgk5xcdmfpjraxwyaljmlh4q` |
| connection/valory/ledger/0.19.0                               | `bafybeidxzeygks5zcky4u2ztcdufzptssgf6uqytxofnn6yta7qq6jsim4` |
| connection/valory/http_server/0.22.0                          | `bafybeiddvj2y25mccqvm5w6bzrn7fnoox7raabhkvpzfldbznxrxkbutmi` |
| connection/valory/p2p_libp2p/0.1.0                            | `bafybeiegkj6v2sltf4mnahuhnevqond5kubnqt6pojgbdo7pgsjthci2rq` |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeielj3jso3wvrarp5n5rq7llpw4vgxybqiyensgjalb5ubfiawwhhu` |
| connection/valory/p2p_libp2p_mailbox/0.1.0                    | `bafybeifdbpetirc5id7v3y6wop5mylqh726mo7jgscl2jl3t4f7vusqcnq` |
| connection/fetchai/local/0.20.0                               | `bafybeigpea5ie23xpzg4k4hcqhzpeeqmnljbqn5ssbbiitc6cfe2nbztba` |
| connection/valory/http_client/0.23.0                          | `bafybeihel6sg2yayxu7lqygaswdgciaxpqrgsbl5rwx74c6znu5qz2edd4` |
| connection/valory/test_libp2p/0.1.0                           | `bafybeifpgckujuplrgxmquakt7dnzesiwmxndpyrn2zuph3lj2iepsnvke` |
| skill/fetchai/echo/0.19.0                                     | `bafybeieqhk2g6l4pitjmuwbtt7n6vx3wawclygjv5cywjjrgay66lzq74u` |
| skill/fetchai/error_test_skill/0.1.0                          | `bafybeiclf3qlci56sk5bw2jh3k52dc4o3hsqmn34msfud5qlsm65j7nrtm` |
| skill/fetchai/http_echo/0.20.0                                | `bafybeie7j4y6ppruwf33fydd34yxaiwnhtpn7ocri37gslsnbvjfs7pg7m` |
| skill/fetchai/erc1155_client/0.28.0                           | `bafybeihkbfkrit3eqhjh4ss2cuaifejlwrb35dwn5l6to23ofhlqwwhm6y` |
| skill/fetchai/erc1155_deploy/0.30.0                           | `bafybeiclrmlf4gcgo7unmtwfp5rmk3fuek7pqhtsgbsoofbptna4o3ps5u` |
| skill/fetchai/error/0.17.0                                    | `bafybeibupgcqs5mofvr5nyfncb7soxoktbuhgudisyht56mm6lpqyqi2rq` |
| skill/fetchai/fipa_dummy_buyer/0.2.0                          | `bafybeic74bc65h5ukwcwbb5wdiw4l2imiga5kxchugdrrd3ux5qfrmzgha` |
| skill/fetchai/generic_buyer/0.26.0                            | `bafybeiepqomeeavejkkc23b5ra2pjt5gihnaueyxlxbscrgpfw63r4hvbm` |
| skill/fetchai/generic_seller/0.27.0                           | `bafybeifc2kaegtslhomd6b4dffmnhozbhscmnkulyciabwh3uspeeoid6q` |
| skill/fetchai/task_test_skill/0.1.0                           | `bafybeic73246oscw5glrvs66b5ptfdzhgnc27le4ivmlz77t7kfjdhyh2e` |
| agent/fetchai/error_test/0.1.0                                | `bafybeiespr3cxvz2mlmuqwdnhyaexhx2hdq3a75axxeqk5ug5to6yqpi3m` |
| agent/fetchai/my_first_aea/0.27.0                             | `bafybeigvzq5ygrsworlbz342hvmcrbauyj2444ugxfahzmfwgudvtwoaf4` |
| agent/open_aea/http_echo/0.1.0                                | `bafybeifypuxx2lp6cyu2memot4ilyaxp5d2fpy3yv5xaa6ijyoftrd4moa` |
| agent/open_aea/my_first_aea/0.1.0                             | `bafybeid76dcmtfg4wixmecwrzrrbkm5zovjqgxussqehrkufd3kklpvcby` |
